@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use base qw( Exporter );
 
-our $VERSION = '0.08';
+our $VERSION = '0.10';
 
 use AnyEvent::RipeRedis::Error;
 
@@ -140,7 +140,6 @@ sub new {
   $self->{handle_params} = $params{handle_params} || {};
   $self->{on_connect}    = $params{on_connect};
   $self->{on_disconnect} = $params{on_disconnect};
-  $self->{on_connect_error} = $params{on_connect_error};
 
   $self->connection_timeout( $params{connection_timeout} );
   $self->read_timeout( $params{read_timeout} );
@@ -232,9 +231,7 @@ sub on_error {
     };
   }
 
-  foreach my $name ( qw( utf8 reconnect on_connect on_disconnect
-      on_connect_error ) )
-  {
+  foreach my $name ( qw( utf8 reconnect on_connect on_disconnect ) ) {
     *{$name} = sub {
       my $self = shift;
 
@@ -962,12 +959,7 @@ sub _abort {
     my $err_msg  = $err->message;
     my $err_code = $err->code;
 
-    if ( defined $self->{on_connect_error} && $err_code == E_CANT_CONN ) {
-      $self->{on_connect_error}->($err);
-    }
-    else {
-      $self->{on_error}->($err);
-    }
+    $self->{on_error}->($err);
 
     if ( %channels && $err_code != E_CONN_CLOSED_BY_CLIENT ) {
       foreach my $name ( keys %channels ) {
@@ -1067,10 +1059,7 @@ AnyEvent::RipeRedis - Flexible non-blocking Redis client
       my $err = $_[1];
 
       if ( defined $err ) {
-        my $err_msg  = $err->message;
-        my $err_code = $err->code;
-
-        warn "[$err_code] $err_msg\n";
+        warn $err->message . "\n";
         $cv->send;
 
         return;
@@ -1082,10 +1071,7 @@ AnyEvent::RipeRedis - Flexible non-blocking Redis client
           my $err   = shift;
 
           if ( defined $err ) {
-            my $err_msg  = $err->message;
-            my $err_code = $err->code;
-
-            warn "[$err_code] $err_msg\n";
+            warn $err->message . "\n";
             $cv->send;
 
             return;
@@ -1130,12 +1116,6 @@ Requires Redis 1.2 or higher, and any supported event loop.
       # handling...
     },
 
-    on_connect_error => sub {
-      my $err = shift;
-
-      # error handling...
-    },
-
     on_error => sub {
       my $err = shift;
 
@@ -1177,9 +1157,9 @@ Enabled by default.
 =item connection_timeout => $fractional_seconds
 
 Specifies connection timeout. If the client could not connect to the server
-after specified timeout, the C<on_connect_error> callback is called with the
-C<E_CANT_CONN> error, or if it not specified, the C<on_error> callback is
-called. The timeout specifies in seconds and can contain a fractional part.
+after specified timeout, the C<on_error> callback is called with the
+C<E_CANT_CONN> error. The timeout specifies in seconds and can contain a
+fractional part.
 
   connection_timeout => 10.5,
 
@@ -1207,11 +1187,11 @@ Disabled by default.
 =item reconnect => $boolean
 
 If the connection to the server was lost and the parameter C<reconnect> is
-TRUE (default), the client try to restore the connection when you execute next
-command. The client try to reconnect only once and, if attempt fails, the error
-object is passed to command callback. If you need several attempts of the
-reconnection, you must retry a command from the callback as many times, as you
-need. Such behavior allows to control reconnection procedure.
+TRUE (default), the client will try to restore the connection when you execute
+next command. The client will try to reconnect only once and, if attempt fails,
+the error object is passed to command callback. If you need several attempts of
+the reconnection, you must retry a command from the callback as many times, as
+you need. Such behavior allows to control reconnection procedure.
 
 Enabled by default.
 
@@ -1250,18 +1230,10 @@ reason.
 
 Not set by default.
 
-=item on_connect_error => $cb->( $err )
-
-The C<on_connect_error> callback is called, when the connection could not be
-established. If this callback isn't specified, the C<on_error> callback is
-called.
-
-Not set by default.
-
 =item on_error => $cb->( $err )
 
 The C<on_error> callback is called when occurred an error, which was affected
-on whole client (e. g. connection error or authentication error). Also the
+on entire client (e. g. connection error or authentication error). Also the
 C<on_error> callback is called on command errors if the command callback is not
 specified. If the C<on_error> callback is not specified, the client just print
 an error messages to C<STDERR>.
@@ -1272,22 +1244,25 @@ an error messages to C<STDERR>.
 
 =head2 <command>( [ @args ] [, $cb->( $reply, $err ) ] )
 
-The full list of the Redis commands can be found here: L<http://redis.io/commands>.
-
-The reply to the command is passed to the callback in first argument. If any
-error occurred during command execution, the error object is passed to the
-callback in second argument. Error object is the instance of the class
-L<AnyEvent::RipeRedis::Error>.
+To execute the command you must call specific method. The reply to the command
+is passed to the callback in first argument. If any error occurred during
+the command execution, the error object is passed to the callback in second
+argument. Error object is an instance of the class L<AnyEvent::RipeRedis::Error>.
 
 The command callback is optional. If it is not specified and any error
 occurred, the C<on_error> callback of the client is called.
 
+The full list of the Redis commands can be found here: L<http://redis.io/commands>.
+
   $redis->get( 'foo',
     sub {
       my $reply = shift;
       my $err   = shift;
 
       if ( defined $err ) {
+        my $err_msg  = $err->message;
+        my $err_code = $err->code;
+
         # error handling...
 
         return;
@@ -1303,6 +1278,9 @@ occurred, the C<on_error> callback of the client is called.
       my $err   = shift;
 
       if ( defined $err ) {
+        my $err_msg  = $err->message;
+        my $err_code = $err->code;
+
         # error handling...
 
         return;
@@ -1324,6 +1302,9 @@ You can execute multi-word commands like this:
       my $err   = shift;
 
       if ( defined $err ) {
+        my $err_msg  = $err->message;
+        my $err_code = $err->code;
+
         # error handling...
 
         return;
@@ -1344,7 +1325,8 @@ convenient.
       my $err   = shift;
 
       if ( defined $err ) {
-        # error handling...
+        my $err_msg  = $err->message;
+        my $err_code = $err->code;
 
         return;
       }
@@ -1435,7 +1417,7 @@ L<http://redis.io/topics/pubsub>
 
 Subscribes the client to the specified channels.
 
-Method can accept two callbacks, C<on_reply> and C<on_message>. The C<on_reply>
+Method can accept two callbacks: C<on_reply> and C<on_message>. The C<on_reply>
 callback is called when subscription to all specified channels will be
 activated. In first argument to the callback is passed the number of channels
 we are currently subscribed. If subscription to specified channels was lost,
@@ -1855,10 +1837,6 @@ Get or set the C<on_connect> callback.
 
 Get or set the C<on_disconnect> callback.
 
-=head2 on_connect_error( [ $callback ] )
-
-Get or set the C<on_connect_error> callback.
-
 =head2 on_error( [ $callback ] )
 
 Get or set the C<on_error> callback.
